mdt.library.opencl_routines.sampling package
============================================

Submodules
----------

mdt.library.opencl_routines.sampling.AbstractSampler module
-----------------------------------------------------------

.. automodule:: mdt.library.opencl_routines.sampling.AbstractSampler
    :members:
    :undoc-members:
    :show-inheritance:

mdt.library.opencl_routines.sampling.MetropolisHastings module
--------------------------------------------------------------

.. automodule:: mdt.library.opencl_routines.sampling.MetropolisHastings
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: mdt.library.opencl_routines.sampling
    :members:
    :undoc-members:
    :show-inheritance:
